- hotplug-cpu-move-tasks-in-empty-cpusets-to-parent-node_online_map-fix.patch removed from -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled
     hotplug cpu move tasks in empty cpusets to parent node_online_map fix
has been removed from the -mm tree.  Its filename was
     hotplug-cpu-move-tasks-in-empty-cpusets-to-parent-node_online_map-fix.patch

This patch was dropped because it was folded into hotplug-cpu-move-tasks-in-empty-cpusets-to-parent.patch

The current -mm tree may be found at http://userweb.kernel.org/~akpm/mmotm/

------------------------------------------------------
Subject: hotplug cpu move tasks in empty cpusets to parent node_online_map fix
From: Cliff Wickman <cpw@xxxxxxx>

As of the October 2007 kernel/cpuset.c patch "Memoryless nodes:
Use N_HIGH_MEMORY for cpusets", cpuset nodes are relative to
the nodes with (HIGH) memory, not relative to all nodes in
node_online_map.

Signed-off-by: Paul Jackson <pj@xxxxxxx>
Acked-by: Cliff Wickman <cpw@xxxxxxx>
Cc: David Rientjes <rientjes@xxxxxxxxxx>
Cc: Paul Menage <menage@xxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxxxxxxxxxxxxxx>
---

 kernel/cpuset.c |    7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff -puN kernel/cpuset.c~hotplug-cpu-move-tasks-in-empty-cpusets-to-parent-node_online_map-fix kernel/cpuset.c
--- a/kernel/cpuset.c~hotplug-cpu-move-tasks-in-empty-cpusets-to-parent-node_online_map-fix
+++ a/kernel/cpuset.c
@@ -1817,7 +1817,8 @@ static void scan_for_empty_cpusets(const
 		cont = cp->css.cgroup;
 		/* Remove offline cpus and mems from this cpuset. */
 		cpus_and(cp->cpus_allowed, cp->cpus_allowed, cpu_online_map);
-		nodes_and(cp->mems_allowed, cp->mems_allowed, node_online_map);
+		nodes_and(cp->mems_allowed, cp->mems_allowed,
+						node_states[N_HIGH_MEMORY]);
 		if ((cpus_empty(cp->cpus_allowed) ||
 		     nodes_empty(cp->mems_allowed))) {
 			/* Move tasks from the empty cpuset to a parent */
@@ -1832,8 +1833,8 @@ static void scan_for_empty_cpusets(const
 
 /*
  * The cpus_allowed and mems_allowed nodemasks in the top_cpuset track
  * cpu_online_map and node_online_map.  Force the top cpuset to track
  * whats online after any CPU or memory node hotplug or unplug event.
  *
  * Since there are two callers of this routine, one for CPU hotplug
  * events and one for memory node hotplug events, we could have coded
_

Patches currently in -mm which might be from cpw@xxxxxxx are

cgroups-mechanism-to-process-each-task-in-a-cgroup.patch
hotplug-cpu-move-tasks-in-empty-cpusets-to-parent.patch
hotplug-cpu-move-tasks-in-empty-cpusets-to-parent-node_online_map-fix.patch
cpusets-update_cpumask-revision.patch
cpusets-update_cpumask-revision-fix.patch
cpusets-update_cpumask-revision-checkpatch-fixes.patch
hotplug-cpu-move-tasks-in-empty-cpusets-to-parent-various-other-fixes.patch
hotplug-cpu-move-tasks-in-empty-cpusets-refinements.patch
cpusets-update_cpumask-documentation-fix.patch

-
@@ -1832,8 +1833,8 @@ static void scan_for_empty_cpusets(const
 /*
  * The cpus_allowed and mems_allowed nodemasks in the top_cpuset track
- * cpu_online_map and node_online_map.  Force the top cpuset to track
- * whats online after any CPU or memory node hotplug or unplug event.
+ * cpu_online_map and node_states[N_HIGH_MEMORY].  Force the top cpuset to
+ * track what's online after any CPU or memory node hotplug or unplug event.
  *
  * Since there are two callers of this routine, one for CPU hotplug
To unsubscribe from this list: send the line "unsubscribe mm-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Kernel Newbies FAQ]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Photo]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux